@@ -20,7 +20,7 @@ public:
   po::options_description getAdvancedOptions(int32_t& numBiasSamples, SalmonOpts& sopt);
   po::options_description getHiddenOptions(SalmonOpts& sopt);
   po::options_description getTestingOptions(SalmonOpts& sopt);
-  po::options_description getDeprecatedOptions(SalmonOpts& sopt);
+  po::options_description getDeprecatedOptions(SalmonOpts& /*sopt*/);
 };
 
 }
