@@ -269,6 +269,11 @@ namespace salmon {
        "format.  By default, output will be directed to "
        "stdout, but an alternative file name can be "
        "provided instead.")
+      ("writeQualities", po::bool_switch(&(sopt.writeQualities))->default_value(salmon::defaults::writeQualities),
+      "This flag only has meaning if mappings are being written (with --writeMappings/-z). "
+      "If this flag is provided, then the output SAM file will contain quality strings as well as "
+      "read sequences. Note that this can greatly increase the size of the output file."
+      )
       ("hitFilterPolicy",
        po::value<string>(&sopt.hitFilterPolicyStr)->default_value(salmon::defaults::hitFilterPolicyStr),
        "[selective-alignment mode only] : Determines the policy by which hits are filtered in selective alignment.  Filtering hits after "
@@ -335,8 +340,8 @@ namespace salmon {
                                        "alevin-developer Options");
     alevindevs.add_options()
       (
-       "indrop", po::bool_switch()->default_value(alevin::defaults::isInDrop),
-       "Use inDrop (not extensively tested) Single Cell protocol for the library. must specify w1 too.")
+       "indropV2", po::bool_switch()->default_value(alevin::defaults::isInDrop),
+       "Use inDropV2 Single Cell protocol for the library. Must specify w1 too.")
       (
        "w1", po::value<std::string>(),
        "Must be used in conjunction with inDrop;")
@@ -410,9 +415,18 @@ namespace salmon {
       (
        "celseq2", po::bool_switch()->default_value(alevin::defaults::isCELSeq2),
        "Use CEL-Seq2 Single Cell protocol for the library.")
+      (
+       "splitseqV1", po::bool_switch()->default_value(alevin::defaults::isSplitSeqV1),
+       "Use Split-SeqV1 Single Cell protocol for the library.")
+      (
+       "splitseqV2", po::bool_switch()->default_value(alevin::defaults::isSplitSeqV2),
+       "Use Split-SeqV2 Single Cell protocol for the library.")
       (
        "quartzseq2", po::bool_switch()->default_value(alevin::defaults::isQuartzSeq2),
        "Use Quartz-Seq2 v3.2 Single Cell protocol for the library assumes 15 length barcode and 8 length UMI.")
+      (
+       "sciseq3", po::bool_switch()->default_value(alevin::defaults::isSciSeq3),
+       "Use sci-RNA-seq3 protocol for the library.")
       (
        "whitelist", po::value<std::string>(),
        "File containing white-list barcodes")
@@ -666,6 +680,12 @@ namespace salmon {
        po::value<uint32_t>(&(sopt.maxReadOccs))->default_value(salmon::defaults::maxReadOccs),
        "Reads \"mapping\" to more than this many places won't be "
        "considered.")
+      ("maxRecoverReadOcc",
+       po::value<uint32_t>(&(sopt.maxRecoverReadOccs))->default_value(salmon::defaults::maxRecoverReadOccs),
+       "Relevant for alevin with \'--sketch\' mode only: if a read has valid seed matches, but no read has matches "
+       "leading to fewer than \"maxReadOcc\" mappings, then try to recover mappings for this read as long as there are "
+       "fewer than \"maxRecoverReadOcc\" mappings."
+       )
       ("noLengthCorrection",
        po::bool_switch(&(sopt.noLengthCorrection))->default_value(salmon::defaults::noLengthCorrection),
        "[experimental] : Entirely disables length correction when "
